@@ -1,22 +1,18 @@
-# vim: ts=2 sw=2 expandtab
+# $Id: Loops.pm 2373 2008-06-29 05:15:05Z rcaputo $
 
 package POE::Test::Loops;
 
 use strict;
 use vars qw($VERSION);
 
-use vars qw($VERSION);
-$VERSION = '1.036_314'; # NOTE - Should be #.### (three decimal places)
+use vars qw($VERSION $REVISION);
+$VERSION = '1.001'; # NOTE - Should be #.### (three decimal places)
+$REVISION = do {my($r)=(q$Revision: 2373 $=~/(\d+)/);sprintf"0.%04d",$r};
 
 use File::Spec;
 use File::Path;
 use File::Find;
 
-use constant TEST_BLOCK_FOR_WHICH => 0x01;
-use constant TEST_BLOCK_FOR_WRONG => 0x02;
-use constant TEST_BLOCK_FOR_RIGHT => 0x04;
-use constant TEST_BLOCK_BEGIN     => 0x08;
-
 ### Find the test libraries.
 
 use lib qw(./lib ../lib);
@@ -49,6 +45,7 @@ sub generate {
 
     my $source = (
 			"#!/usr/bin/perl -w\n" .
+			"# \$Id\$\n" .
 			"\n" .
 			"use strict;\n" .
 			"\n" .
@@ -148,91 +145,14 @@ sub _get_loop_cfg {
 
   open SOURCE, "<$fqmn" or die $!;
   while (<SOURCE>) {
-    # Not in a test block.
-    unless ($in_test_block) {
-
-      # Proper =for syntax.
-      if (/^=for\s+poe_tests\s+(\S.*?)$/) {
-        push @test_source, $1;
-        $in_test_block = TEST_BLOCK_FOR_RIGHT;
-        next;
-      }
-
-      # Not sure which =for syntax is in use.
-      if (/^=for\s+poe_tests\s*$/) {
-        $in_test_block = TEST_BLOCK_FOR_WHICH;
-        next;
-      }
-
-      if (/^=begin\s+(poe_tests)\s*$/) {
-        $in_test_block = TEST_BLOCK_BEGIN;
-        next;
-      }
-
-      # Some random line.  Do nothing.
-      next;
-    }
-
-    # Which test block format are we in?
-    if ($in_test_block & TEST_BLOCK_FOR_WHICH) {
-      # If the following line is blank, then we're probably in the
-      # wrong, multi-line kind originally documented and now
-      # deprecated.
-      if (/^\s*$/) {
-        $in_test_block = TEST_BLOCK_FOR_WRONG;
-        next;
-      }
-
-      # The following line is not blank, so it appears we're in a
-      # properly formated =for paragraph.
-      $in_test_block = TEST_BLOCK_FOR_RIGHT;
+    if ($in_test_block) {
+      $in_test_block = 0, next if /^=cut\s*$/;
       push @test_source, $_;
       next;
     }
 
-    # The =begin syntax ends with an =end.
-    if ($in_test_block & TEST_BLOCK_BEGIN) {
-      if (/^=end\s*poe_tests\s*$/) {
-        $in_test_block = 0;
-        next;
-      }
-
-      # Be helpful?
-      die "=cut not the proper way to end =begin poe_tests" if /^=cut\s*$/;
-
-      push @test_source, $_;
-      next;
-    }
-
-    # The proper =for syntax ends on a blank line.
-    if ($in_test_block & TEST_BLOCK_FOR_RIGHT) {
-      if (/^$/) {
-        $in_test_block = 0;
-        next;
-      }
-
-      # Be helpful?
-      die "=cut not the proper way to end =for poe_tests" if /^=cut\s*$/;
-
-      push @test_source, $_;
-      next;
-    }
-
-    # The wrong =for syntax ends on =cut.
-    if ($in_test_block & TEST_BLOCK_FOR_WRONG) {
-      if (/^=cut\s*$/) {
-        $in_test_block = 0;
-        next;
-      }
-
-      # Be helpful?
-      die "=end not the proper way to end =for poe_tests" if /^=end/;
-
-      push @test_source, $_;
-      next;
-    }
-
-    die "parser in unknown state: $in_test_block";
+    next unless /^=for\s+poe_tests\s*/;
+    $in_test_block = 1;
   }
 
   shift @test_source while @test_source and $test_source[0] =~ /^\s*$/;
